==> landtax-1.0.0-20160518.023814-5-sources.jar: cn/gtmap/landtax/service/YdqcService.java <==
package cn.gtmap.landtax.service;

import cn.gtmap.landtax.entity.*;
import cn.gtmap.landtax.model.query.SbZsQuery;
import cn.gtmap.landtax.model.query.SwDjSyQuery;
import cn.gtmap.landtax.model.query.YdqcZdQuery;
import cn.gtmap.landtax.model.query.ZdQuery;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Created by Administrator on 2014/9/2.
 */
public interface YdqcService {
    //宗地疑点清册
    Page findZdList(ZdQuery zdQuery, Pageable pageable);
    List<SwDjSyTemp> findSytzByProid(String proid);
    void zdYdqcWfEnd(String proid)  throws  Exception;
    void zdYdqcWfDel(String proid);
    List<Object> getZdydqcTzList(HashMap param);

    //征收疑点清册
    List<SSjZsydqcTd> getTdZsByIds(List<String> hcxmBdIds);
    List<SSjZsydqcFc> getFcZsByIds(List<String> hcxmBdIds);
    List<String> getzsYearList(String szdm);
    Object findZsListJson(SbZsQuery sbZsQuery, String szdm, Pageable pageable);
    void zsYdqcWfEnd(String proid, String szdm) throws  Exception;
    void zsYdqcWfDel(String proid, String szdm);

    //申报征收公用
    public List<HashMap<String, Object>> sumNynseByGlbm(String szdm, String glbm);
    void saveOrUpdateTdSbXgsqb(TdSbXgsqb tdSbXgsqb) throws  Exception;
    Object getZtById(String id,String hcxmlx);

    public StringBuffer getZsListSql(String szdm,SbZsQuery sbZsQuery);

    BigDecimal getTotalTdNynseByProid(String proid);

    BigDecimal getTotalFcNynseByProid(String proid);

    public BigDecimal getRkseByProid(String proid, String szdm, String ssnf, String sssq);

    List<Zd> findZdListTz(ZdQuery zdQuery);
}

==> landtax-1.0.0-20161009.022418-24-sources.jar: cn/gtmap/landtax/service/YdqcService.java <==
package cn.gtmap.landtax.service;

import cn.gtmap.landtax.entity.*;
import cn.gtmap.landtax.model.query.SbZsQuery;
import cn.gtmap.landtax.model.query.SwDjSyQuery;
import cn.gtmap.landtax.model.query.YdqcZdQuery;
import cn.gtmap.landtax.model.query.ZdQuery;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Created by Administrator on 2014/9/2.
 */
public interface YdqcService {
    //宗地疑点清册
    Page findZdList(ZdQuery zdQuery, Pageable pageable);
    List<SwDjSyTemp> findSytzByProid(String proid);
    void zdYdqcWfEnd(String proid)  throws  Exception;
    void zdYdqcWfDel(String proid);
    List<Object> getZdydqcTzList(HashMap param);

    //征收疑点清册
    List<SSjZsydqcTd> getTdZsByIds(List<String> hcxmBdIds);
    List<SSjZsydqcFc> getFcZsByIds(List<String> hcxmBdIds);
    List<String> getzsYearList(String szdm);
    Object findZsListJson(SbZsQuery sbZsQuery, String szdm, Pageable pageable);
    void zsYdqcWfEnd(String proid, String szdm) throws  Exception;
    void zsYdqcWfDel(String proid, String szdm);

    //申报征收公用
    public List<HashMap<String, Object>> sumNynseByGlbm(String szdm, String glbm);
    void saveOrUpdateTdSbXgsqb(TdSbXgsqb tdSbXgsqb) throws  Exception;
    Object getZtById(String id,String hcxmlx);

    public StringBuffer getZsListSql(String szdm,SbZsQuery sbZsQuery);

    BigDecimal getTotalTdNynseByProid(String proid);

    BigDecimal getTotalFcNynseByProid(String proid);

    public BigDecimal getRkseByProid(String proid, String szdm, String ssnf, String sssq);

    List<Zd> findZdListTz(ZdQuery zdQuery);
    /**
     * 国土宗地核查疑点数据
     * @return
     */
    public String getZdydTzListJson();
    //宗地已下发疑点清册
    Page findZdYxfList(ZdQuery zdQuery, Pageable pageable);
    List<Object> getZdYxfTzList(HashMap param);
}
